# Conjunto

## Description
Conjunto is a Django application framework using [HTMX](https://htmx.org), [tabler.io](https://tabler.io), [crispy-forms](https://github.com/django-crispy-forms/django-crispy-forms) and more.

## Installation
You can install the package by using pip (best using a virtualenv):

```bash
pip install conjunto
```

## Usage
There is an own section in the [documentation](https://conjunto.readthedocs.io) available.


## Development setup
For setting up development environment you will need pytest, pre-commit and black. You can install these by running (in the project directory):

```bash
pip install .[dev]
```

## Contributing
Pull requests and general ideas are welcome. For major changes, please open an issue first to discuss what you would like to change.

## License
The Conjunto project is open-source and licensed under the MIT License. Please keep in mind that Conjunto uses many other libraries, which may be under different licenses.